@@ -34,21 +34,6 @@ int binomial_coefficient(int n, int k){
 }
 
 
-// This function is taken from
-// https://stackoverflow.com/questions/29724083/trying-to-write-a-setdiff-function-using-rcpparmadillo-gives-compilation-error
-// [[Rcpp::export]]
-arma::uvec std_setdiff(arma::uvec& x, arma::uvec& y) {
-
-  std::vector<int> a = arma::conv_to< std::vector<int> >::from(arma::sort(x));
-  std::vector<int> b = arma::conv_to< std::vector<int> >::from(arma::sort(y));
-  std::vector<int> out;
-
-  std::set_difference(a.begin(), a.end(), b.begin(), b.end(),
-                      std::inserter(out, out.end()));
-
-  return arma::conv_to<arma::uvec>::from(out);
-}
-
 // Function to sample an integer given a set of probabilities
 // [[Rcpp::export]]
 int sample_int(const arma::rowvec& probs){
@@ -65,3 +50,17 @@ int sample_int(const arma::rowvec& probs){
 
   return arma::as_scalar(matches);
 }
+
+// Truncated beta distribution
+double rtruncbeta(int shape1, int shape2, double trunc = 1) {
+  int i = 0;
+  double x;
+  while(i < 1000){
+    x = arma::chi2rnd(2 * shape1);
+    x = x / (x + arma::chi2rnd(2 * shape2));
+
+    if(x < trunc) break;
+    ++i;
+  }
+  return x;
+}
