@@ -1,63 +1,64 @@
 #include "RcppArmadillo.h"
 #include "leapandshift.h"
-#include "distfuns.h"
+#include "distances.h"
 #include "partitionfuns.h"
+#include <cmath>
+
 
-// via the depends attribute we tell Rcpp to create hooks for
-// RcppArmadillo so that the build process will know what to do
-//
 // [[Rcpp::depends(RcppArmadillo)]]
 
-void update_alpha(arma::mat& alpha,
-                  arma::vec& alpha_acceptance,
-                  arma::vec& alpha_old,
+// Initialize latent ranks as provided by rho_init, or randomly:
+arma::mat initialize_rho(Rcpp::Nullable<arma::mat> rho_init, int n_items, int n_clusters){
+  if(rho_init.isNotNull()){
+    return arma::repmat(Rcpp::as<arma::mat>(rho_init), 1, n_clusters);
+  } else {
+    return arma::shuffle(arma::repmat(arma::regspace<arma::mat>(1, 1, n_items), 1, n_clusters));
+  }
+};
+
+double update_alpha(arma::vec& alpha_acceptance,
+                  const double& alpha_old,
                   const arma::mat& rankings,
-                  int& alpha_index,
-                  int& cluster_index,
-                  const arma::mat& rho_old,
+                  const int& cluster_index,
+                  const arma::vec& rho_old,
                   const double& alpha_prop_sd,
                   const std::string& metric,
                   const double& lambda,
-                  const int& n_items,
                   const Rcpp::Nullable<arma::vec> cardinalities = R_NilValue,
                   const Rcpp::Nullable<arma::vec> logz_estimate = R_NilValue) {
 
 
   // Set the number of assessors. Not using the variable from run_mcmc because
-  // here we want the number of assessors in this cluster #cluster_index
+  // here we want the number of assessors in this cluster
   int n_assessors = rankings.n_cols;
+  int n_items = rho_old.n_elem;
 
-  // Sample an alpha proposal
   double alpha_proposal = std::exp(arma::randn<double>() * alpha_prop_sd +
-                              std::log(alpha_old(cluster_index)));
+                              std::log(alpha_old));
 
-  double rank_dist = rank_dist_matrix(rankings, rho_old.col(cluster_index), metric);
+  double rank_dist = rank_dist_sum(rankings, rho_old, metric);
 
   // Difference between current and proposed alpha
-  double alpha_diff = alpha_old(cluster_index) - alpha_proposal;
+  double alpha_diff = alpha_old - alpha_proposal;
 
   // Compute the Metropolis-Hastings ratio
   double ratio =
     alpha_diff / n_items * rank_dist +
     lambda * alpha_diff +
     n_assessors * (
-        get_partition_function(n_items, alpha_old(cluster_index), cardinalities, logz_estimate, metric) -
+        get_partition_function(n_items, alpha_old, cardinalities, logz_estimate, metric) -
           get_partition_function(n_items, alpha_proposal, cardinalities, logz_estimate, metric)
-    ) + std::log(alpha_proposal) - std::log(alpha_old(cluster_index));
+    ) + std::log(alpha_proposal) - std::log(alpha_old);
 
   // Draw a uniform random number
   double u = std::log(arma::randu<double>());
 
   if(ratio > u){
-    alpha(cluster_index, alpha_index) = alpha_proposal;
     ++alpha_acceptance(cluster_index);
+    return alpha_proposal;
   } else {
-    alpha(cluster_index, alpha_index) = alpha_old(cluster_index);
+    return alpha_old;
   }
-
-
-  alpha_old(cluster_index) = alpha(cluster_index, alpha_index);
-
 }
 
 
@@ -65,7 +66,7 @@ void update_rho(arma::cube& rho, arma::vec& rho_acceptance, arma::mat& rho_old,
                 int& rho_index, const int& cluster_index, const int& rho_thinning,
                 const double& alpha_old, const int& leap_size, const arma::mat& rankings,
                 const std::string& metric, const int& n_items, const int& t,
-                const arma::uvec& element_indices, bool& rho_accepted) {
+                const arma::uvec& element_indices) {
 
   arma::vec rho_cluster = rho_old.col(cluster_index);
 
@@ -75,16 +76,12 @@ void update_rho(arma::cube& rho, arma::vec& rho_acceptance, arma::mat& rho_old,
   double prob_backward, prob_forward;
 
   leap_and_shift(rho_proposal, indices, prob_backward, prob_forward,
-                 rho_cluster, leap_size);
+                 rho_cluster, leap_size, !((metric == "cayley") || (metric == "ulam")));
 
-  // These distances do not work with the computational shortcut
-  if(metric == "cayley"){
-    indices = arma::regspace<arma::uvec>(0, n_items - 1);
-  }
 
   // Compute the distances to current and proposed ranks
-  double dist_new = rank_dist_matrix(rankings.rows(indices), rho_proposal(indices), metric);
-  double dist_old = rank_dist_matrix(rankings.rows(indices), rho_cluster(indices), metric);
+  double dist_new = rank_dist_sum(rankings.rows(indices), rho_proposal(indices), metric);
+  double dist_old = rank_dist_sum(rankings.rows(indices), rho_cluster(indices), metric);
 
 
   // Metropolis-Hastings ratio
@@ -97,9 +94,6 @@ void update_rho(arma::cube& rho, arma::vec& rho_acceptance, arma::mat& rho_old,
   if(ratio > u){
     rho_old.col(cluster_index) = rho_proposal;
     ++rho_acceptance(cluster_index);
-    rho_accepted = true;
-  } else {
-    rho_accepted = false;
   }
 
   // Save rho if appropriate
@@ -110,3 +104,5 @@ void update_rho(arma::cube& rho, arma::vec& rho_acceptance, arma::mat& rho_old,
 
 }
 
+
+
